==> jumbo-pbx-0.1.tar.gz: jumbo-pbx-0.1/pbx/views.py <==
# -*- coding: utf-8 -*-
'''
Created on 4/nov/2011

@author: simone cittadini
'''
import sys

from django.http import  HttpResponseRedirect, HttpResponse
from django.shortcuts import render_to_response
from django.template.context import RequestContext
from django.contrib.auth.decorators import login_required

from jumbo.apps.auth.models import JumboUser
from jumbo.apps.profile.models import SCProfiles
from jumbo.utils.functions import get_settings

from pbx.switch.models import Account


SERVERURL = get_settings('switch.settings', 'SERVERURL')
SERVERIP = get_settings('switch.settings', 'SERVERIP')

def psse(message):
    print >> sys.stderr, message
    

@login_required
def dashboard_pbx(request):
    u = SCProfiles.objects.get(user=request.user)
    upbx = u.get_profile('UtentePBX', 'pbx.utenti.models')
    acc = Account.objects.get(utentepbx=upbx)
    return render_to_response('utenti/homepage.html',
                              locals(), RequestContext(request))


#def load_utenti(file_utenti):
#    login_creati = []
#    for l in file_utenti.readlines():
#        interno, protocollo, cognome_nome = l.split('\t')
#        if protocollo == 'sip':
#            posizione_primo_spazio = cognome_nome.find(' ')
#            if  posizione_primo_spazio == -1:
#                cognome = cognome_nome.strip()
#                nome = cognome_nome.strip()
#            else:
#                cognome = cognome_nome[0:posizione_primo_spazio].strip()
#                nome = cognome_nome[posizione_primo_spazio+1:].strip()
#            login = "%s.%s" % (cognome.lower().replace(' ', ''),
#                               nome.lower().replace(' ', ''))
#            while login in login_creati:
#                login = "%s2" % login
#            login_creati.append(login)
#            mail = "%s.%s@primasgr.it" % (cognome.lower().replace(' ', ''),
#                                          nome.lower().replace(' ', ''))
#            ju = JumboUser.objects.create_user(login, mail, 'secret11')
#            ju.first_name = nome
#            ju.last_name = cognome
#            ju.save()
#            u = UtentePBX.objects.get(nome=login)
#            Account.objects.create(utentepbx=u, name=interno, nat='no',
#                                   setvar='rec=no')
            
#def load_telefoni(file_telefoni, file_estensioni):
#    telefoni = {}
#    for l in file_telefoni.readlines():
#        id, mac = l.split('\t')[0], l.split('\t')[1]
#        telefoni[id] = mac
#    for l in file_estensioni.readlines():
#        id, id_telefono, interno = l.split('\t')
#        mac = telefoni[id_telefono]
#        interno = interno.strip()
#        try:
#            DeviceCisco.objects.create(nome='cisco del %s' % interno,
#                                   mac_address=mac,
#                                   account=Account.objects.get(name=interno))
#        except Account.DoesNotExist:
#            print "non trovato %s %s" % (interno, mac)

# import fatto sui file di prima
# da rendere a plugin
#def import_da_csv(request):
#    if request.method == 'POST':
#        form = FormImportCsv(request.POST, request.FILES)
#        if form.is_valid():
#            if form.cleaned_data['csv_utenti']:
#                load_utenti(form.cleaned_data['csv_utenti'])
#            if form.cleaned_data['csv_telefoni'] and \
#                    form.cleaned_data['csv_estensioni']:
#                load_telefoni(form.cleaned_data['csv_telefoni'],
#                              form.cleaned_data['csv_estensioni'])
#            return HttpResponseRedirect('/pbx/import_da_csv/')
#    else:
#        form = FormImportCsv()
#    return render_to_response('import_da_csv.html', locals(),
#                              RequestContext(request))

==> jumbo-pbx-0.1.1.tar.gz: jumbo-pbx-0.1.1/pbx/views.py <==
# -*- coding: utf-8 -*-
'''
Created on 4/nov/2011

@author: simone cittadini
'''
import sys

from django.http import  HttpResponseRedirect, HttpResponse
from django.shortcuts import render_to_response
from django.template.context import RequestContext
from django.contrib.auth.decorators import login_required
from django.shortcuts import get_object_or_404

#from jumbo.apps.auth.models import JumboUser
from jumbo.apps.profile.models import SCProfiles
from jumbo.utils.functions import get_settings

from pbx.switch.models import Account, SERVERURL, Device
from pbx.utenti.models import UtentePBX, EnabledCookie, PersonalPhonebookEntry,\
    BlacklistEntry

from pbx.switch.models import Account, VoiceMail


SERVERURL = get_settings('switch.settings', 'SERVERURL')
SERVERIP = get_settings('switch.settings', 'SERVERIP')

def psse(message):
    print >> sys.stderr, message
    

@login_required
def dashboard_pbx(request):
    u = SCProfiles.objects.get(user=request.user)
    upbx = u.get_profile('UtentePBX', 'pbx.utenti.models')
    acc = Account.objects.get(utentepbx=upbx)
    vm = VoiceMail.objects.get(mailbox=acc.name)
    return render_to_response('admin/pbx/utenti/dashboard_pbx.html',
                              locals(), RequestContext(request))
    
@login_required
def retrieve__personalphonebook(request, utente_pbx_id):
    """
    Torna una lista delle entry nel personal phonebook dell'utente ad argomento
    """
    u = get_object_or_404(UtentePBX, pk=utente_pbx_id)
    qs = PersonalPhonebookEntry.objects.filter(utentepbx=u)
    return render_to_response('admin/pbx/utenti/retrieve__personalphonebook.html',
                              locals(), RequestContext(request))


#def load_utenti(file_utenti):
#    login_creati = []
#    for l in file_utenti.readlines():
#        interno, protocollo, cognome_nome = l.split('\t')
#        if protocollo == 'sip':
#            posizione_primo_spazio = cognome_nome.find(' ')
#            if  posizione_primo_spazio == -1:
#                cognome = cognome_nome.strip()
#                nome = cognome_nome.strip()
#            else:
#                cognome = cognome_nome[0:posizione_primo_spazio].strip()
#                nome = cognome_nome[posizione_primo_spazio+1:].strip()
#            login = "%s.%s" % (cognome.lower().replace(' ', ''),
#                               nome.lower().replace(' ', ''))
#            while login in login_creati:
#                login = "%s2" % login
#            login_creati.append(login)
#            mail = "%s.%s@primasgr.it" % (cognome.lower().replace(' ', ''),
#                                          nome.lower().replace(' ', ''))
#            ju = JumboUser.objects.create_user(login, mail, 'secret11')
#            ju.first_name = nome
#            ju.last_name = cognome
#            ju.save()
#            u = UtentePBX.objects.get(nome=login)
#            Account.objects.create(utentepbx=u, name=interno, nat='no',
#                                   setvar='rec=no')
            
#def load_telefoni(file_telefoni, file_estensioni):
#    telefoni = {}
#    for l in file_telefoni.readlines():
#        id, mac = l.split('\t')[0], l.split('\t')[1]
#        telefoni[id] = mac
#    for l in file_estensioni.readlines():
#        id, id_telefono, interno = l.split('\t')
#        mac = telefoni[id_telefono]
#        interno = interno.strip()
#        try:
#            DeviceCisco.objects.create(nome='cisco del %s' % interno,
#                                   mac_address=mac,
#                                   account=Account.objects.get(name=interno))
#        except Account.DoesNotExist:
#            print "non trovato %s %s" % (interno, mac)

# import fatto sui file di prima
# da rendere a plugin
#def import_da_csv(request):
#    if request.method == 'POST':
#        form = FormImportCsv(request.POST, request.FILES)
#        if form.is_valid():
#            if form.cleaned_data['csv_utenti']:
#                load_utenti(form.cleaned_data['csv_utenti'])
#            if form.cleaned_data['csv_telefoni'] and \
#                    form.cleaned_data['csv_estensioni']:
#                load_telefoni(form.cleaned_data['csv_telefoni'],
#                              form.cleaned_data['csv_estensioni'])
#            return HttpResponseRedirect('/pbx/import_da_csv/')
#    else:
#        form = FormImportCsv()
#    return render_to_response('import_da_csv.html', locals(),
#                              RequestContext(request))
